export default {
  id: 'career',
  title: '工作经验',
  showProgress: true,
  progress: 0,
  get: {
    action: '/zws/v1/enrollment/careers?project_id=1001',
    callback(data) {
      return data.map(item => {
        const { start_date: startDate, end_date: endDate } = item
        if (startDate) {
          item.times = [startDate + '', endDate + '']
        }
        return item
      })
    }
  },
  update: {
    action: '/zws/v1/enrollment/careers/batch-upload',
    data: { project_id: 1001 },
    beforeRequest(data) {
      const records = data.map(item => {
        let [startDate, endDate] = item.times
        item.start_date = startDate
        item.end_date = endDate
        return [
          'start_date',
          'end_date',
          'company_name_cn',
          'industry',
          'dept_cn',
          'position_cn',
          'job_type',
          'annual_salary',
          'job_desc_cn',
          'company_profile'
        ].reduce((result, key) => {
          result[key] = item[key]
          return result
        }, {})
      })
      return { records }
    }
  },
  form: {
    options: {
      labelWidth: '140px'
    },
    hasAdd: true,
    items: [
      {
        type: 'date-picker-from-to-form',
        elemType: 'monthrange',
        label: '工作时间',
        model: 'times',
        rangeSeparator: '至',
        startPlaceholder: '请选择开始时间',
        endPlaceholder: '请选择结束时间',
        attrs: { 'value-format': 'yyyyMM' },
        rules: [{ required: true, message: '请选择教育时间', trigger: 'blur' }]
      },
      {
        type: 'input-form',
        label: '工作单位',
        model: 'company_name_cn',
        rules: [{ required: true, message: '请输入工作单位', trigger: 'blur' }]
      },
      {
        type: 'select-form',
        values: [{ label: '请选择', value: 0 }],
        label: '行业类别',
        model: 'industry',
        rules: [
          { required: true, message: '请选择行业类别', trigger: 'change' }
        ]
      },
      {
        type: 'input-form',
        label: '工作部门',
        model: 'dept_cn',
        rules: [{ required: true, message: '请输入工作部门', trigger: 'blur' }]
      },
      {
        type: 'input-form',
        label: '工作职位',
        model: 'position_cn',
        rules: [{ required: true, message: '请输入工作职位', trigger: 'blur' }]
      },
      {
        type: 'select-form',
        values: [
          { label: '请选择', value: 0 },
          { label: '高层管理（总经理/副总经理以上级）', value: 1 },
          { label: '高级管理（总助/执行主任/执行总监级）', value: 2 },
          { label: '中级管理（总监/部门经理级）', value: 3 },
          { label: '初级经理（主管/一级经理级）', value: 4 },
          { label: '职员', value: 5 },
          { label: '其他', value: 9 }
        ],
        label: '职位类型',
        model: 'job_type',
        rules: [
          { required: true, message: '请选择职位类型', trigger: 'change' }
        ]
      },
      {
        type: 'input-form',
        label: '工作年薪（万元）',
        model: 'annual_salary',
        rules: [{ required: true, message: '请输入工作年薪', trigger: 'blur' }]
      },
      {
        type: 'input-form',
        label: '工作描述',
        model: 'job_desc_cn',
        attrs: {
          type: 'textarea',
          placeholder:
            '请详细描述您的职责范围，工作任务以及取得的成绩等，填写文字在100个字以上评定等级，少于不计算，内容越详细，等级越高。（字限3000字以内）',
          rows: '8',
          maxlength: '3000',
          'show-word-limit': true
        },
        rules: [{ required: true, message: '请输入工作描述', trigger: 'blur' }]
      },
      {
        type: 'input-form',
        label: '公司（单位）简介',
        model: 'company_profile',
        attrs: {
          type: 'textarea',
          placeholder:
            '300字左右，包括所属行业在业内的位置，经营时间，业务规模，发展前景等信息',
          rows: '4'
        },
        rules: [
          { required: true, message: '请输入公司（单位）简介', trigger: 'blur' }
        ]
      }
    ]
  }
}
