export default {
  id: 'education',
  title: '教育背景',
  showProgress: true,
  progress: 0,
  get: {
    action: '/zws/v1/enrollment/educations?project_id=1000',
    callback(data) {
      return data.map(item => {
        const { start_date: startDate, end_date: endDate } = item
        if (startDate) {
          item.times = [(startDate + '').replace(/([\d]{4})([\d]{2})/gi, '$1-$2'), (endDate + '').replace(/([\d]{4})([\d]{2})/gi, '$1-$2')]
        }
        return item
      })
    }
  },
  update: {
    action: '/zws/v1/enrollment/educations/batch-upload',
    data: { project_id: 1000 },
    callback(data) {
      return data.map(item => {
        let [startDate, endDate] = item.times
        item.start_date = parseInt(startDate.replace(/-/gi, ''))
        item.end_date = parseInt(endDate.replace(/-/gi, ''))
        return item
      })
    }
  },
  form: {
    hasAdd: true,
    options: {
      labelWidth: '160px'
    },
    model: [
      {
        times: [],
        start_date: null,
        end_date: null,
        school_name_cn: '',
        school_city: '',
        major_cn: '',
        degree: 0
      }
    ],
    items: [
      /* 教育时间 */
      {
        'type': 'date-picker-from-to-form',
        'elemType': 'monthrange',
        'label': '教育时间',
        'required': true,
        'disabled': false,
        'label-width': '160px',
        'model': 'times',
        'model-width': '300px',
        'rangeSeparator': '至',
        'startPlaceholder': '请选择开始时间',
        'endPlaceholder': '请选择结束时间',
        'attrs': { 'value-format': 'yyyy-MM' },
        'rules': [{ 'required': true, 'message': '请选择教育时间', 'trigger': 'blur' }]
      },
      /* 学校名称 */
      {
        'type': 'input-form',
        'label': '学校名称',
        'required': true,
        'model': 'school_name_cn',
        'model-width': '300px',
        'placeholder': '请输入学校名称',
        'rules': [{ 'required': true, 'message': '请输入学校名称', 'trigger': 'blur' }]
      },
      /* 专业名称 */
      {
        'type': 'input-form',
        'label': '专业名称',
        'required': true,
        'model': 'major_cn',
        'model-width': '300px',
        'placeholder': '请输入专业名称',
        'rules': [{ 'required': true, 'message': '请输入专业名称', 'trigger': 'blur' }]
      },
      /* 学历/学位 */
      {
        'type': 'select-form',
        'label': '学历/学位',
        'required': true,
        'model': 'degree',
        'model-width': '300px',
        'placeholder': '请选择',
        'values': [
          { label: '专科', value: 1 },
          { label: '本科', value: 2 },
          { label: '本科/学士', value: 3 },
          { label: '硕士研究生', value: 4 },
          { label: '研究生/硕士', value: 5 },
          { label: '博士研究生', value: 6 },
          { label: '研究生/博士', value: 7 },
          { label: '其他', value: 9 }
        ],
        'rules': [
          { 'required': true, 'message': '请选择学历/学位', trigger: 'change' }
        ]
      }
    ]
  }
}
